@@ -186,7 +186,7 @@ class greenMan(pygame.sprite.Sprite):
 		for monster in lstMonsters:
 			if monster.scared:
 				monster.Eaten()
-				config.greenHits = config.greenHits+1
+				config.greenHits += 1
 				if config.gameSound:
 					self._killSound.play(loops=0, maxtime=0, fade_ms=0)
 			else:
