@@ -185,7 +185,7 @@ class purpleMan(pygame.sprite.Sprite):
 		for monster in lstMonsters:
 			if monster.scared:
 				monster.Eaten()
-				config.purpleHits = config.purpleHits+1
+				config.purpleHits += 1
 				if config.gameSound:
 					self._killSound.play(loops=0, maxtime=0, fade_ms=0)
 			else:
